BackoffParams

Struct BackoffParams 

pub struct BackoffParams {
    factor: u32,
    base: Duration,
    max: Duration,
    jitter: Ratio,
    disable: bool,
}

Fields

factor: u32

Exponential backoff exponent.

base: Duration

Exponential backoff base delay.

max: Duration

Exponential max delay.

jitter: Ratio

Exponential backoff jitter as a ratio of the backoff delay, numerator:denominator.

disable: bool

Disable retries and just fail after one failed attempt.

Implementations

Source

impl BackoffParams

pub const fn new( base: Duration, max: Duration, factor: u32, jitter: Ratio, ) -> Self

pub fn disabled() -> Self

pub async fn retry<S, T>( &self, state: S, f: impl for<'a> Fn(&'a mut S, usize) -> BoxFuture<'a, Result<T>>, ) -> Result<T>

pub async fn retry_if<Fut, T>( &self, max_retries: u32, should_retry: impl Fn(&Error) -> bool, f: impl Fn() -> Fut, ) -> Result<T>
where Fut: Future<Output = Result<T>>,

Like retry but stops after max_retries retries and only retries when should_retry returns true for the error. The closure takes no arguments; capture any needed state in the closure itself.

pub fn backoff(&self, delay: Duration) -> Duration